@@ -101,10 +101,12 @@ static void zvt_term_updated(ZvtTerm *term, int mode);
 static void clone_col(unsigned short **dest, unsigned short *from);
 static void zvt_term_real_copy_clipboard (ZvtTerm *term);
 static void zvt_term_real_paste_clipboard (ZvtTerm *term);
+static void zvt_term_real_selection_changed (ZvtTerm *term);
 
 /* callbacks from update layer */
 void vt_draw_text(void *user_data, struct vt_line *line, int row, int col, int len, int attr);
 void vt_scroll_area(void *user_data, int firstrow, int count, int offset, int fill);
+static void vt_selection_changed(void *user_data);
 
 /* static data */
 
@@ -136,6 +138,7 @@ enum
   COPY_CLIPBOARD,
   PASTE_CLIPBOARD,
   SCROLL,
+  SELECTION_CHANGED,
   LAST_SIGNAL
 };
 static guint term_signals[LAST_SIGNAL] = { 0 };
@@ -242,6 +245,13 @@ zvt_term_class_init (ZvtTermClass *class)
 		    GTK_TYPE_NONE, 1, 
 		    GTK_TYPE_INT);
 
+    term_signals[SELECTION_CHANGED] =
+    gtk_signal_new ("selection_changed",
+		    GTK_RUN_LAST,
+		    GTK_CLASS_TYPE (object_class),
+		    GTK_SIGNAL_OFFSET (ZvtTermClass, selection_changed),
+		    gtk_marshal_VOID__VOID,
+		    GTK_TYPE_NONE, 0);
 
   object_class->destroy = zvt_term_destroy;
 
@@ -268,6 +278,7 @@ zvt_term_class_init (ZvtTermClass *class)
   term_class->copy_clipboard = zvt_term_real_copy_clipboard;
   term_class->paste_clipboard = zvt_term_real_paste_clipboard;
   term_class->scroll = zvt_term_scroll;
+  term_class->selection_changed = zvt_term_real_selection_changed;
 
   /* Setup default key bindings */
   binding_set = gtk_binding_set_by_class(term_class);
@@ -304,7 +315,8 @@ zvt_term_init (ZvtTerm *term)
   /* set rendering callbacks */
   term->vx->draw_text = vt_draw_text;
   term->vx->scroll_area = vt_scroll_area;
-  term->vx->cursor_state = vt_cursor_state;
+  term->vx->selection_changed = vt_selection_changed;
+term->vx->cursor_state = vt_cursor_state;
 
   term->shadow_type = GTK_SHADOW_NONE;
   term->term_window = NULL;
@@ -3345,6 +3357,20 @@ vt_scroll_area(void *user_data, int firstrow, int count, int offset, int fill)
   }
 }
 
+static void
+vt_selection_changed (void *user_data)
+{
+  gtk_signal_emit_by_name (GTK_OBJECT (user_data), "selection_changed");
+}
+
+
+static void
+zvt_term_real_selection_changed (ZvtTerm *term)
+{
+  return;
+}
+
+
 /**
  * zvt_term_set_del_key_swap:
  * @term:   A &ZvtTerm widget.
